The function map.plot creates a map using geographical (x,y)-coordinates.
This is thought for spatially dependent data of which coordinates are available.
Multivariate outliers are marked.
The function map.plot shows mutlivariate outliers in a map.
If symb=FALSE (default), only two colors and no special symbols are used to
mark multivariate outliers (the outliers are marked red).
If symb=TRUE different symbols and colors are used.
The symbols (cross means big value, circle means little value) are selected according to
the robust mahalanobis distance based on the adjusted mcd estimator (see function symbol.plot)
Different colors (red means big value, blue means little value)
according to the euclidean distances of the observations (see function color.plot)
are used. For details see Filzmoser et al. (2005).
References
P. Filzmoser, R.G. Garrett, and C. Reimann.
Multivariate outlier detection in exploration geochemistry.
Computers & Geosciences, 31:579-587, 2005.